/*

  Potentiometer Position Monitor.
 
  Sketch adapted from "Bargraph" example by Tom Igoe.

  Changed to "Dot" mode as current not available for "Bar" mode

  Object: Provide position indication of a 10 turn potentiometer with respect
    to centre, (5 turns).
    Monitored over portion of range in this case 50% ie; +/- 25% either side
    of centre. Approx 25% to 75% of total.

  Two banks of 10 LEDs. Each bank wired common cathode via single 220ohm 
    limiting resistor and reverse voltage blocking diode to "Bank select" 
    output pins.These pins are PWM capable to control LED brightness.
    Blocking diodes used as LEDs usually only have a 5V reverse voltage
    maximum which will be the case when a Bank is "OFF". Do NOT use power
    diodes here as they will not respond quick enough to PWM signals.
    1N914/1N4148 small signal diodes are OK.
    Corresponding anodes connected together ie; 1 to 1, 2 to 2 etc counting
    from centre. Each digital output connected to 2 LED anodes.

  Banks arranged with a LED of a different colour between them to indicate
    "Zero" or centre position. Wired to Ground via 330ohm limiting resistor
    and driven from digital output 2 via a diode.
    Also connected via a diode to 3.3V so LED is dimly at all times. Disregard
    if this not required.
    Diodes here are to isolate 2 different supplies and MUST be used. As above
    1N914/1N4148 OK.

  Mapping ADC outut from -20 to +21 provides a virtual centre zero
    potentiometer with ascending numerals either side of centre. Negative
    numbers are no use here so when in the negative region LED banks are
    switched and re-mapped ADC multiplied by -1 which reverses sign so 
    converting negative to positive
    Non symetrical mapping moves the LED display slightly so centre LED is ON 
    when pot moved equally either side of centre. 48.8% to 51.2% of rotation
     
  LEDs are switched on in turn for approx 2.5% of pot rotation in either
    direction. Last LED in each bank remains ON when pot past monitoring
    extremities or "out of range".

  Monitored range of the Potentiometer can be changed by changing the mapping
    range. Example -25 to +26 would monitor 40%, -30 to +31 33.3% and so on.

  The virtual zero point can also be moved by changing the symmetry of the
    mapping. In this sketch changing mapping to -15 to +26 would move the 
    virtual zero point about 12.5% away from the actual centre of pot travel.

  This is a fairly simple method of converting a normal pot to centre zero
    I have used this to control speed and direction of a small dc motor
    using a single pot with centre off or stopped. Used for this purpose a 
    small "dead zone" needs to be created in the centre.

*/

// these constants won't change:
const int analogPin = A0;   // the pin that the potentiometer is attached to
const int ledCount = 11;    // the number of LEDs in the bar graph
const int ledUp = 9;        //LED bank nose up
const int ledDn = 10;       //LED bank nose down

int ledPins[] = {
  2, 3, 4, 5, 6, 7, 8, A4, A5, 11, 12
};   // an array of pin numbers to which LEDs are attached

void setup() {
  // loop over the pin array and set them all to output:
  for (int thisLed = 0; thisLed < ledCount; thisLed++) {
    pinMode(ledPins[thisLed], OUTPUT);
    //set led bank switching pins to output:
    //Note LOW is active ie; led bank ON:
    pinMode(ledUp, OUTPUT);
    pinMode(ledDn, OUTPUT);
    //Serial.begin(9600);
  }
}

void loop() {
  // read the potentiometer:
  int sensorReading = analogRead(analogPin);
  
  //create virtual centre zero potentiometer:
  int ledLevel = map(sensorReading, 0, 1023, -30, 31);
  
      if (ledLevel > 0)
      {
      digitalWrite(ledUp, HIGH);//ledUp nose up bank OFF:
      analogWrite(ledDn, 180);//ledDn nose down bank ON:
      //pwm to control led brightness, 0=LOW (full on), 255=HIGH (off):
      }

      // change sign for ledLevel when pot below centre:
      if (ledLevel < 0) 
      {
      ledLevel=(ledLevel * -1);
      //switch led banks:
      analogWrite(ledUp, 180);//ledUp nose up bank bank ON:
      digitalWrite(ledDn, HIGH);//ledDn nose down bank OFF:
      //pwm to control led brightness, 0=LOW (full on), 255=HIGH (off):
      }

      //keep LED 10 on when potentiometer outside monitor range:
      if (ledLevel >= 10)
      {
        ledLevel = 10;
      }
 
  
      // loop over the LED array:
      for (int thisLed = 0; thisLed < ledCount; thisLed++) 
        {
          // turn the pin for this element on:
          if (thisLed == ledLevel) 
          {
          digitalWrite(ledPins[thisLed], HIGH);
          }
          // turn off all pins other than the ledLevel:
          else 
          {
          digitalWrite(ledPins[thisLed], LOW);
          }
          
          
          //{ 
            //Serial.println(ledLevel);
          //}
        }
    }
